#include <iostream>
#include <cassert>
#include <cstring>
#include <string>
#include <cstdio>
#include <vector>
#include <cstdlib>
#include <map>
#include <cmath>

using namespace std;

const int MAX_BOUNDARY_LENGTH = 1000;
const int ARRAY_LENGTH = 3 * MAX_BOUNDARY_LENGTH;
const int startingPoint = ARRAY_LENGTH / 2;

#ifdef DISABLE_BASH_COLOUR_CODING
	const string beginMessage, endMessage, beginError, endError, beginWarning, endWarning;
#else
	const string beginMessage = "\033[37m";
	const string endMessage = "\033[0m";
	const string beginError = "\033[31;1m";
	const string endError = endMessage;
	const string beginWarning = "\033[31;4m";
	const string endWarning = endMessage;
#endif


const int hasX = 1;
const int hasY = 2;
const int hasZ = 4;

int dx[] = {1, 0, -1};
int dy[] = {0, 1,  1};
long double Xcoord[] = {1.0L, 0.5L};
long double Ycoord[] = {0.0L, sqrt(3.0L) / 2.0L};

long double factor;

string coordinate(long double x) {
	char tmp[100];
	sprintf(tmp, "%.14Lf", x * factor);
	return string(tmp);
}

string coordinates(int x, int y) {
	long double xx = x - startingPoint;
	long double yy = y - startingPoint;
	long double drawX = xx * Xcoord[0] + yy * Xcoord[1];
	long double drawY = xx * Ycoord[0] + yy * Ycoord[1];
	string xCoord = coordinate(drawX);
	string yCoord = coordinate(drawY);
	char tmp[200];
	sprintf(tmp, "(%s,%s)", xCoord.c_str(), yCoord.c_str());
	return string(tmp);
}

struct instructie {
	char dir;
	int len;
};

int sgn(int x) {
	if (x > 0) return 1;
	if (x < 0) return -1;
	return 0;
}

struct point {
	int x, y;
	point() : x(0), y(0) {}
	point(int _x, int _y) : x(_x), y(_y) {}
	bool operator<(const point& other) const {
		if (x != other.x) return x < other.x;
		return y < other.y;
	}
	bool operator==(const point& other) const {
		return x == other.x && y == other.y;
	}
};

string coordinates(const point& p) {
	return coordinates(p.x, p.y);
}

int connections[ARRAY_LENGTH][ARRAY_LENGTH];
map<point,point> XLines, YLines, ZLines;

void addXLine(int x, int y) {
	point startPoint(x, y - 1), endPoint(x + 1, y - 1);
	map<point,point>::iterator it = XLines.find(startPoint);
	if (it != XLines.end()) {
		startPoint = it->second;
		XLines.erase(it);
	}
	XLines.insert(make_pair(endPoint, startPoint));
}

void addYLine(int x, int y) {
	point startPoint(x, y - 1), endPoint(x, y);
	map<point,point>::iterator it = YLines.find(startPoint);
	if (it != YLines.end()) {
		startPoint = it->second;
		YLines.erase(it);
	}
	YLines.insert(make_pair(endPoint, startPoint));
}

void addZLine(int x, int y) {
	point startPoint(x + 1, y - 1), endPoint(x, y);
	map<point,point>::iterator it = ZLines.find(startPoint);
	if (it != ZLines.end()) {
		startPoint = it->second;
		ZLines.erase(it);
	}
	ZLines.insert(make_pair(endPoint, startPoint));
}

void solve() {
	int C;
	cin >> C;
	int x = startingPoint;
	int y = startingPoint;
	long double drawingX = 0.0L;
	long double drawingY = 0.0L;
	long double minX = drawingX;
	long double maxX = drawingX;
	long double minY = drawingY;
	long double maxY = drawingY;
	vector<instructie> instructies;
	memset(connections, 0, sizeof connections);
	for (int i = 0; i < C; i++) {
		char dir;
		int len;
		cin >> dir >> len;
		assert(dir == 'x' || dir == 'y' || dir == 'z');
		assert(len != 0);
		assert(len >= -MAX_BOUNDARY_LENGTH && len <= MAX_BOUNDARY_LENGTH);
		int copyX = x;
		int copyY = y;
		for (int j = 0; j < abs(len); j++) {
			int oldX = copyX;
			int oldY = copyY;
			int plusX = sgn(len) * dx[dir - 'x'];
			int plusY = sgn(len) * dy[dir - 'x'];
			copyX += plusX;
			copyY += plusY;
			drawingX += plusX * Xcoord[0] + plusY * Xcoord[1];
			drawingY += plusX * Ycoord[0] + plusY * Ycoord[1];
			if (dir == 'x') continue;
			int bitmask = (dir == 'y' ? hasY : hasZ);
			if (len > 0) {
				connections[copyY][copyX] |= bitmask;
			}
			else {
				connections[oldY][oldX] |= bitmask;
			}
		}
		x += len * dx[dir - 'x'];
		y += len * dy[dir - 'x'];
		assert(x == copyX && y == copyY);
		instructies.push_back((instructie) {dir, len});
		minX = min(minX, drawingX);
		maxX = max(maxX, drawingX);
		minY = min(minY, drawingY);
		maxY = max(maxY, drawingY);
	}
	assert(minX < maxX && minY < maxY);
	long double padding = 0.1L;
	minX -= padding;
	minY -= padding;
	maxX += padding;
	maxY += padding;
	long double xFactor = 18.0L / (maxX - minX);
	long double yFactor = 27.0L / (maxY - minY);
	factor = min(xFactor,yFactor);
	cout << "\\ \\vfill" << endl;
	cout << "\\begin{tikzpicture}[line width=" << factor * 1.5L << "mm,line join=round,line cap=round,draw=blue!60!black]" << endl;
	point beginpunt(startingPoint, startingPoint);
	point tweedepunt(startingPoint, startingPoint);
	tweedepunt.x += instructies[0].len * dx[instructies[0].dir - 'x'];
	tweedepunt.y += instructies[0].len * dy[instructies[0].dir - 'x'];
	if (x != startingPoint || y != startingPoint) {
		// the curve is not closed
		x = tweedepunt.x;
		y = tweedepunt.y;
		cout << "\t\\draw ";
		for (int i = 1; i < C; i++) {
			char dir = instructies[i].dir;
			int len = instructies[i].len;
			if (i > 1) cout << "\n\t   -- ";
			cout << coordinates(x, y);
			x += len * dx[dir - 'x'];
			y += len * dy[dir - 'x'];
		}
		cout << ";" << endl;
	}
	else {
		// the curve is indeed closed
		cout << "\t\\fill[blue!75!Gold] (0,0)" << endl;
		for (int i = 0; i < C; i++) {
			char dir = instructies[i].dir;
			int len = instructies[i].len;
			x += len * dx[dir - 'x'];
			y += len * dy[dir - 'x'];
			cout << "\t                      -- " << coordinates(x, y);
			if (i < C - 1)
				cout << endl;
			else
				cout << ";" << endl;
		}
		XLines.clear();
		YLines.clear();
		ZLines.clear();
		for (int y = 0; y < ARRAY_LENGTH; y++) {
			int binnen = 0;
			for (int x = 0; x < ARRAY_LENGTH; x++) {
				if (connections[y][x] & hasY) {
					binnen = 1 - binnen;
					addYLine(x, y);
				}
				else if (binnen) {
					addYLine(x, y);
				}
				if (binnen || connections[y][x] & hasX) {
					addXLine(x, y);
				}
				if (connections[y][x] & hasZ) {
					binnen = 1 - binnen;
					addZLine(x, y);
				}
				else if (binnen) {
					addZLine(x, y);
				}
				if (binnen) {
					connections[y + 1][x] |= hasX;
				}
			}
		}
		map<point,point> allLines[] = {XLines, YLines, ZLines};
		for (int i = 0; i < 3; i++) {
			for (map<point,point>::iterator it = allLines[i].begin(); it != allLines[i].end(); it++) {
				point a = it->first;
				point b = it->second;
				if (i == (int) (instructies[0].dir - 'x') && (a == beginpunt || b == beginpunt)) {
					if (b == beginpunt) swap(a,b);
					a = tweedepunt;
					if (a == b) continue;
				}
				cout << "\t\\draw " << coordinates(a) << " -- " << coordinates(b) << ";" << endl;
			}
		}
	}
	cout << "\t\\begin{scope}[Gold]" << endl;
	cout << "\t\t\\node[circle,fill,minimum width=" << factor * 2.5L << "mm] (beginpunt) at " << coordinates(beginpunt) << " {};" << endl;
	cout << "\t\t\\draw[line width=" << max(factor * 1.5L, 1.0L) << "mm] (beginpunt.center) -- " << coordinates(tweedepunt) << ";" << endl;
	cout << "\t\\end{scope}" << endl;
	cout << "\\end{tikzpicture}" << endl;
	cout << "\\vfill" << endl;
}

int main() {
	cerr << beginMessage << "make-a-drawing: a program that converts input files to TikZ-based LaTeX files" << endl;
	cerr << "in order to make a drawing of the test cases." << endl;
	cerr << endl;
	cerr << "Please verify the validity of the test data before attempting to draw!" << endl;
	cerr << endl;
	cerr << "USAGE:" << endl;
	cerr << "./verifier < sample.in" << endl;
	cerr << "./make-a-drawing < sample.in > sample.tex" << endl;
	cerr << "pdflatex -interaction nonstopmode sample.tex" << endMessage << endl;
	int T;
	cin >> T;
	cout << "\\documentclass{article}" << endl;
	cout << "\\usepackage[margin=0cm]{geometry}" << endl;
	cout << "\\usepackage[svgnames]{xcolor}" << endl;
	cout << "\\usepackage{tikz}" << endl;
	cout << "\\usetikzlibrary{calc,arrows,decorations.markings}" << endl;
	cout << endl;
	cout << "\\pagestyle{empty}" << endl;
	cout << endl;
	cout << "\\begin{document}" << endl;
	cout << "\\centering" << endl;
	cout << "\\pgfmathsetmacro{\\halfworteldrie}{sqrt(3) / 2}" << endl;
	for (int i = 0; i < T; i++) {
		cout << "% test case " << i+1 << endl;
		if (i) cout << "\\newpage" << endl;
		solve();
		if (i < T - 1) cout << endl;
	}
	cout << "\\end{document}" << endl;
	return 0;
}
