#include <iostream>
#include <cassert>
#include <vector>
#include <cstring>
#include <cstdio>
#include <cctype>
#include <set>

using namespace std;

const long long MAX_N = 250;
const long long MAX_M = 1000000;
const long long MOD = 100000000;

struct bigint {
	vector<char> val;
	bigint() {
		val.push_back('0');
	}
	bigint(long long _v) {
		char tmp[30];
		sprintf(tmp, "%lld", _v);
		int l = strlen(tmp);
		for (int i = l - 1; i >= 0; i--) {
			assert(isdigit(tmp[i]));
			val.push_back(tmp[i]);
		}
	}
	bigint& operator+=(const bigint& other) {
		int c = 0;
		unsigned l = 1 + max(val.size(), other.val.size());
		val.resize(l, '0');
		for (unsigned i = 0; i < l; i++) {
			val[i] += (i < other.val.size() ? other.val[i] - '0' : 0) + c;
			c = (val[i] - '0') / 10;
			assert(c == 0 || c == 1);
			val[i] = ((val[i] - '0') % 10) + '0';
		}
		while (val.size() >= 2 && val.back() == '0') val.pop_back();
		return *this;
	}
	bigint operator+(const bigint& other) const {
		return bigint(*this) += other;
	}
	friend ostream& operator<<(ostream& os, const bigint& b) {
		for (vector<char>::const_reverse_iterator r_it = b.val.rbegin(); r_it != b.val.rend(); r_it++) {
			os << *r_it;
		}
		return os;
	}
	bool operator==(const bigint& other) const {
		return val == other.val;
	}
	bool operator!=(const bigint& other) const {
		return !(*this == other);
	}
	long long modulo(long long mod) const {
		long long multiplier = 1;
		long long ret = 0;
		for (vector<char>::const_iterator it = val.begin(); it != val.end(); it++) {
			ret += multiplier * (*it - '0');
			ret %= mod;
			multiplier *= 10;
			multiplier %= mod;
		}
		return ret;
	}
};

long long N, M;
bool played[2 * MAX_N][2 * MAX_N];
int visited[2 * MAX_N];

int dfs(int node, int iterationNumber) {
	if (visited[node] >= 0) return 0;
	visited[node] = iterationNumber;
	int ret = 1;
	for (int nextNode = 0; nextNode < 2 * N; nextNode++) {
		if (!played[node][nextNode]) {
			ret += dfs(nextNode, iterationNumber);
		}
	}
	return ret;
}

bigint numSolutions[2 * MAX_N];
int pred[2 * MAX_N];

void solve() {
	// step 1: read input
	cin >> N >> M;
	assert(N >= 1 && N <= MAX_N);
	assert(M >= N * N && M <= MAX_M);
	memset(played, 0, sizeof played);
	for (int i = 0; i < M; i++) {
		int A, B;
		cin >> A >> B;
		assert(A >= 1 && A <= 2 * N);
		assert(B >= 1 && B <= 2 * N);
		assert(A < B);
		A--; B--;
		played[A][B] = true;
		played[B][A] = true;
	}
	// step 2: find components of complement graph
	memset(visited, -1, sizeof visited);
	vector<int> v;
	int iterationNumber = 0;
	for (int i = 0; i < 2 * N; i++) {
		int cur = dfs(i, iterationNumber);
		if (cur != 0) {
			v.push_back(cur);
			iterationNumber++;
		}
	}
	// step 3: subset sum
	for (int i = 0; i < 2 * N; i++) {
		numSolutions[i] = bigint();
		pred[i] = -1;
	}
	numSolutions[0] = 1;
	for (unsigned i = 1; i < v.size(); i++) {
		for (int j = 2 * N - 1; j >= v[i]; j--) {
			bool wasZero = (numSolutions[j] == 0);
			numSolutions[j] += numSolutions[j - v[i]];
			bool isZero = (numSolutions[j] == 0);
			if (wasZero && !isZero) {
				pred[j] = i;
			}
		}
	}
	// step 4: print solution
	cerr << "actual number of solutions: " << numSolutions[N] << endl;
	cout << numSolutions[N].modulo(MOD) << endl;
	set<int> excludeComponents;
	for (int remain = N; remain > 0; ) {
		int p = pred[remain];
		assert(p >= 1 && p < (int) v.size());
		excludeComponents.insert(p);
		remain -= v[p];
	}
	set<int> firstSolution;
	for (int i = 0; i < 2 * N; i++) {
		if (excludeComponents.find(visited[i]) == excludeComponents.end()) {
			firstSolution.insert(i);
		}
	}
	assert((int) firstSolution.size() == N);
	assert(*firstSolution.begin() == 0);
	for (set<int>::iterator it = firstSolution.begin(); it != firstSolution.end(); it++) {
		cout << (it == firstSolution.begin() ? "" : " ") << (*it) + 1;
	}
	cout << endl;
	// step 5: verify solution, just to be sure (you wouldn't have to do this)
	set<int> otherTeam;
	for (int i = 0; i < 2 * N; i++) otherTeam.insert(i);
	for (set<int>::iterator it = firstSolution.begin(); it != firstSolution.end(); it++)
		assert(otherTeam.erase(*it));
	assert((int) otherTeam.size() == N);
	for (set<int>::iterator it = firstSolution.begin(); it != firstSolution.end(); it++) {
		for (set<int>::iterator jt = otherTeam.begin(); jt != otherTeam.end(); jt++) {
			assert(played[*it][*jt]);
		}
	}
}

int main() {
	int T;
	cin >> T;
	for (int i = 0; i < T; i++)
		solve();
	return 0;
}
