// O(C) solution using area formula for simple polygons, the so-called shoelace
// formula. For this we try triangles of various shapes and sizes and make sure
// the answers coincide. (This is an unnecessary step, the sole purpose of which
// is to make absolutely sure that the jury test data is indeed correct. A team
// may suffice with picking a single shape of triangle.)

#include <iostream>
#include <cassert>
#include <cmath>
#include <vector>
#include <set>

using namespace std;

const int MAX_NUM_CASES = 1000;
const int MAX_BOUNDARY = 1000;

long double shapesAndSizes[][3][2] = {{{ 1.0L, 0.0L}, { 0.0L, 1.0L}, {-1.0L, 1.0L}},
                                      {{ 1.0L, 0.0L}, { 0.5L, 1.0L}, {-0.5L, 1.0L}},
                                      {{ 1.0L, 0.0L}, { 1.0L, 1.0L}, { 0.0L, 1.0L}},
                                      {{ 1.0L, 0.0L}, { 0.5L, sqrt(3.0L) / 2.0L}, {-0.5L, sqrt(3.0L) / 2.0L}}, // equilateral
                                      {{ 3.0L, 2.0L}, { 2.0L, 5.0L}, {-1.0L, 3.0L}}}; // very strange

// Nice little trick from http://stackoverflow.com/a/18078435
template<class T, size_t N>
size_t size(T (&)[N]) { return N; }

struct point {
	long double x, y;
	point() : x(0.0L), y(0.0L) {}
	point(long double _x, long double _y) : x(_x), y(_y) {}
	point operator+=(const point& other) {
		x += other.x;
		y += other.y;
		return *this;
	}
	point operator+(const point& other) const {
		return point(*this) += other;
	}
};

vector<long double> singleTriangleArea;

void precalc() {
	for (unsigned c = 0; c < size(shapesAndSizes); c++) {
		point cur;
		long double area = 0.0L;
		int dir[] = {0, 2, 1};
		int l[] = {1, 1, -1};
		for (int i = 0; i < 3; i++) {
			point oldCur = cur;
			cur += point(l[i] * shapesAndSizes[c][dir[i]][0], l[i] * shapesAndSizes[c][dir[i]][1]);
			area += oldCur.x * cur.y - cur.x * oldCur.y;
		}
		singleTriangleArea.push_back(abs(area));
		//cerr << "  singleTriangleArea[" << c << "] = " << singleTriangleArea[c] << endl;
	}
}

int solve() {
	int C;
	cin >> C;
	vector<point> cur(size(shapesAndSizes));
	vector<long double> area(size(shapesAndSizes), 0.0L);
	for (int i = 0; i < C; i++) {
		char dir;
		int l;
		cin >> dir >> l;
		assert(dir == 'x' || dir == 'y' || dir == 'z');
		assert(l != 0);
		assert(l >= -MAX_BOUNDARY && l <= MAX_BOUNDARY);
		for (unsigned c = 0; c < size(shapesAndSizes); c++) {
			long double oldX = cur[c].x;
			long double oldY = cur[c].y;
			cur[c].x += l * shapesAndSizes[c][dir - 'x'][0];
			cur[c].y += l * shapesAndSizes[c][dir - 'x'][1];
			area[c] += oldX * cur[c].y - cur[c].x * oldY;
		}
	}
	set<int> foundAreas;
	for (unsigned c = 0; c < size(shapesAndSizes); c++) {
		area[c] = abs(area[c] / singleTriangleArea[c]);
		area[c] = round(area[c]);
		int cur = (int) (area[c] + 0.5L);
		foundAreas.insert(cur);
	}
	assert(foundAreas.size() == 1); // make sure all shapes and sizes yield the same answer
	return *foundAreas.begin();
}

int main() {
	precalc();
	int T;
	cin >> T;
	assert(T >= 1 && T <= MAX_NUM_CASES);
	for (int i = 0; i < T; i++) {
		cout << solve() << endl;
	}
	return 0;
}
