/*
Solution by Stijn Duijzer.

// @EXPECTED_RESULTS@: CORRECT

Running time: O(n*m)
Memory usage: O(n*m)
*/

#include <iostream>
#include <vector>
using namespace std;

const int N = 100, M = 100;

struct Block
{
  void Reset()
  {
    edges.clear();
    hasP = false;
    checked = false;
  }

  bool hasP;
  vector<Block*> edges;

  bool checked;

} block[N][M];

int main()
{
	int runs; cin >> runs;
	
	for(int run = 1; run <= runs; run++)
	{
		int n, m, p, c; cin >> n >> m >> p >> c;	
    int X = n, Y = m;
		for(int x = 0; x < X; x++)
      for(int y = 0; y < Y; y++)
        block[x][y].Reset();
    
    // read in power generator lines
    for(int i = 0; i < p; i++)
    {
      int x,y; cin >> x >> y;
      block[x][y].hasP = true;
    }
    
    // read in connection lines
    for(int i = 0; i < c; i++)
    {
      int x,y; cin >> x >> y;
      char D; cin >> D;

      if ( D == 'R' )
      {
        block[x][y].edges.push_back( &block[x+1][y] );
        block[x+1][y].edges.push_back( &block[x][y] );
      }

      if ( D == 'U' )
      {
        block[x][y].edges.push_back( &block[x][y+1] );
        block[x][y+1].edges.push_back( &block[x][y] );
      }
    }

    // calculate number of connected components without power source
    int ans = 0;

		for(int x = 0; x < X; x++)
    {
      for(int y = 0; y < Y; y++)
      {
        if ( block[x][y].checked == false )
        {
          // dfs from x,y
          bool found_generator = false;
          
          vector<Block*> stack; stack.push_back( &block[x][y] );
          while ( !stack.empty() )
          {
            Block* cur = stack[stack.size()-1]; stack.pop_back();

            if ( cur->checked ) continue;
            if ( cur->hasP ) found_generator = true;
            cur->checked = true;
            for( int i = 0; i < cur->edges.size(); i++ )
              stack.push_back( cur->edges[i] );
          }


          if ( found_generator == false ) ans++;
        }
      }
    }

    // output answer
		cout << ans << endl;
	}	

	return 0;	
}
