// Solution to Risk
// Time complexitiy: O(N*M*D^4) (note: can be optimized to O(N*M*D^2))
// Memory complexity: O(N*M) (note: can be optimized to O(N) or O(M))
//
// Stijn Duijzer

#include <iostream>
using namespace std;

// probability that Mark wins given m,n
double f[1001][1001];
int D, M, N;
double Dinv;

double find_answer( int m, int n, int h1, int h2 )
{
  // reply with 1 dice
  double ans1 = Dinv * ((h1-1) * f[m][n-1] + (D-(h1-1)) * f[m-1][n]);

//cout << "call " << m << " " << n << " " << h1 << " " << h2 << " --> " << ans1 << endl;
  if ( n == 1 ) return ans1;

  // reply with 2 dice (easy to optimize this)
  double ans2 = 0;
  for(int def1 = 1; def1 <= D; def1++) 
    for(int def2 = 1; def2 <= def1; def2++)
    {
      double rp = Dinv * Dinv * (def1 == def2 ? 1 : 2 );
      
      // calculate deltas in armies
      int dm = 0, dn = 0;
      if ( h2 >= 1 )
      {
        if ( def1 < h1 ) dn++; else dm++;
        if ( def2 < h2 ) dn++; else dm++;
      }
      else 
      {
        if ( def1 < h1 && def2 < h1 ) dn++; else dm++;
      } 

      ans2 += rp * f[m-dm][n-dn];
    }

  // return lowest of ans1 and ans2 (defender chooses)
  return ans1 < ans2 ? ans1 : ans2;
}

int main()
{
  int runs; cin >> runs;
  for(int run = 1; run <= runs; run++)
  {
    cin >> D >> M >> N;
    Dinv = 1.0/D;
   
    // when has mark won:
    for(int m = 0; m <= M; m++) {f[m][0] = 1;}
    
    // when has mark lost:
    for(int n = 0; n <= N; n++) {f[0][n] = f[1][n] = 0;}

    // increase m
    for(int m = 2; m <= M; m++)
    {
      double p = Dinv;
      if ( m >= 3 ) p *= Dinv;
      if ( m >= 4 ) p *= Dinv;
      // increase n
      for(int n = 1; n <= N; n++)
      {  
        f[m][n] = 0;

        // m and n are given, now throw
        for(int h1 = 1; h1 <= D; h1++)
        {
          if ( m == 2 ) // only one attacking dice for m = 2
          {
            f[m][n] += p * find_answer( m, n, h1, 0 );
          }
          else // two attacking dice for m > 2, find second highest
          {
            for(int h2 = 1; h2 <= h1; h2++)
            {
              int options = 0;
              if ( m == 3 )
              {
                options = (h1==h2?1:2);
              }
              else
              {
                options = (h2-1) * 6 / (h1==h2?2:1);
                options += 1     * 6 / (h1==h2?6:2);
              }
              
              f[m][n] += p * options * find_answer( m, n, h1, h2 );
            }  
          }
        }
      }
    }
    
    cout.precision(5);
    cout << f[M][N] << endl;
  }
  

  return 0;
}
