#include <cctype>
#include <cstdio>
#include <cstdlib>
#include <fstream>
#include <iostream>
#include <set>
#include <sstream>
#include <string>
#include <vector>

using namespace std;

ifstream inputfile;
ofstream commentsfile;

void protectedGetline(string& s) {
	if (!getline(inputfile, s)) {
		cerr << "Error: input file ended unexpectedly." << endl;
		commentsfile << "Error: input file ended unexpectedly." << endl;
		exit(1);
	}
}

vector<string> splitSpaces(const string& s) {
	stringstream ss(s);
	vector<string> ret;
	string tmp;
	while (getline(ss, tmp, ' '))
		ret.push_back(tmp);
	return ret;
}

template<class T>
set<T> convertToSet(const vector<T> &v) {
	set<T> ret;
	for (typename vector<T>::const_iterator it = v.begin(); it != v.end(); it++) {
		ret.insert(*it);
	}
	return ret;
}

const int MAXN = 1000002;
int available[MAXN];
int dist[MAXN];

int main(int argc, char* argv[]) {
	// check for missing arguments:
	if (argc < 4) {
		cerr << "Error in invocation of " << argv[0] << ": missing argument";
		if (argc < 3) cerr << 's';
		cerr << "." << endl;
		cout << "Internal error." << endl;
		return 1;
	}
	// open inputfile:
	inputfile.open(argv[1]);
	if (inputfile.fail()) {
		cerr << "Error in " << argv[0] << ": failed to open input file (\"" << argv[1] << "\")." << endl;
		cout << "Internal error." << endl;
		return 1;
	}
	// open commentsfile:
	string s(argv[3]);
	if (s.empty() || s[s.size() - 1] != '/') s.push_back('/');
	s.append("judgemessage.txt");
	commentsfile.open(s.c_str());
	if (commentsfile.fail()) {
		cerr << "Error in " << argv[0] << ": failed to open comments file (\"" << s << "\")." << endl;
		cout << "Internal error." << endl;
		return 1;
	}
	// produce a warning if there are too many arguments:
	if (argc > 4) {
		commentsfile << "Warning: ignoring additional arguments (";
		for (int i = 4; i < argc; i++) {
			if (i > 4) cerr << ", ";
			commentsfile << '"' << argv[i] << '"';
		}
		commentsfile << ")." << endl;
	}
	// actual verification starts HERE:
	int T;
	protectedGetline(s);
	sscanf(s.c_str(), "%d", &T);
	int numWrongAnswers = 0;
	for (int i = 0; i < T; i++) {
		int N, answer, checktank = 0;
		protectedGetline(s);
		sscanf(s.c_str(), "%d", &N);
		cerr << N << endl;
		cin >> s; // perhaps check team answer input format here
		if(s == "IMPOSSIBLE")
			answer = -1; 
		else
			answer = atoi(s.c_str());
		cerr << "answer: " << answer << endl;		
		for(int j=1; j<=N; j++) {
			protectedGetline(s); // perhaps check input format and extra spaces etc.	
			vector<string> list = splitSpaces(s);			
			for(int k=0; k<(signed)list.size(); k++) {
				//cerr << list[k] << ' ';
			}
			available[i] = atoi(list[0].c_str());
			dist[i] = atoi(list[1].c_str());
			checktank = checktank + available[i] - dist[i];			
			//cerr << endl;
		}
		if(checktank < 0) {
			if(answer == -1)
				commentsfile << "OK!" << endl;
			else
			numWrongAnswers++;									
		}
		else {
			if(answer < 1) {
				numWrongAnswers++;	// this was added to catch segfaults due to negative array index referencing	
			}
			else {
				// now similate from answer to answer-1
				int index;
				int tank;
				bool ok = true;
				tank = 0;		
				for(int j=0; j<N; j++) {
					index = answer + j;
					if (index > N)
						index -= N;
					tank += available[index];
					tank -= dist[index];
					if(tank < 0) {
						ok = false;
						break;
					}
				}
				if(ok)
					commentsfile << "OK!" << endl;
				else
					numWrongAnswers++;		
			}		
		}
	}
	
	/* this does not work anymore due to inferior cin's above
	if (cin.fail() || cin.eof()) {
		commentsfile << "Problem with team output: missing final newline." << endl;
		return 43;
	}
	if (getline(cin, s)) {
		commentsfile << "Problem with team output: additional data after final test case." << endl;
		return 43;
	}*/
	commentsfile << "Summary: ";
	if (numWrongAnswers) {
		if (numWrongAnswers == 1)
			commentsfile << "there was 1 wrong answer." << endl;
		else
			commentsfile << "there were " << numWrongAnswers << " wrong answers." << endl;
		return 43;
	}
	else {
		commentsfile << "all OK!" << endl;
		return 42;
	}
}
