// O(26 * 26 * L) solution, correct and fast enough.
// 
// For this algorithm, the proof of correctness is done by reducing it to a
// decision problem. If S is a string of length L and X is any letter, we let
// occ(X, S) denote the number of occurrences of X in S. Now if Y is any letter,
// we can produce a valid anagram of S that doesn't start with the letter Y if
// and only if both of the following conditions are met:
//    a)  occ(X, S) <= ceil(L / 2) holds for any letter X;
//    b)  occ(Y, S) <= floor(L / 2).
// It is not so hard to see that these conditions are necessary. One uses a
// greedy construction in order to show that the conditions are also sufficient.

#include <iostream>
#include <cctype>
#include <cassert>
#include <cstring>
#include <string>

using namespace std;

const int MAX_NUM_CASES = 5000;
const int MAX_LEN = 100000;
int occurrences[26];

bool hasSolutionNotStartingWith(char forbiddenFirstChar, int remainingLength) {
	for (int i = 0; i < 26; i++) {
		if (occurrences[i] > (remainingLength + 1) / 2)
			return false;
	}
	return occurrences[forbiddenFirstChar - 'a'] <= remainingLength / 2;
}

string solve() {
	string str;
	cin >> str;
	int l = str.size();
	assert(l > 0 && l <= MAX_LEN);
	memset(occurrences, 0, sizeof occurrences);
	for (int i = 0; i < l; i++) {
		assert(islower(str[i]));
		occurrences[str[i] - 'a']++;
	}
	for (int i = 0; i < 26; i++) {
		if (occurrences[i] > (l + 1) / 2) {
			return "IMPOSSIBLE";
		}
	}
	char sol[MAX_LEN + 3];
	for (int i = 0; i < l; i++) {
		bool done = false;
		for (char nextChar = 'a'; nextChar <= 'z'; nextChar++) {
			if (i > 0 && nextChar == sol[i - 1]) {
				continue;
			}
			if (occurrences[nextChar - 'a'] == 0) {
				continue;
			}
			occurrences[nextChar - 'a']--;
			if (hasSolutionNotStartingWith(nextChar, l - i - 1)) {
				sol[i] = nextChar;
				done = true;
				break;
			}
			occurrences[nextChar - 'a']++;
		}
		assert(done);
	}
	sol[l] = '\0';
	return string(sol);
}

int main() {
	int T;
	cin >> T;
	assert(T > 0 && T <= MAX_NUM_CASES);
	for (int i = 0; i < T; i++)
		cout << solve() << endl;
	return 0;
}
