// O(26 * L) solution, correct and faster.
// 
// Proving the correctness of this algorithm is tricky. I think it's easiest to
// first prove the correctness for my other solution (josse-1-OK.cpp) and then
// simplify the other algorithm to this version by case analysis.
// 
// Interestingly, even though the worst-case runtime for this algorithm is 
// lower, it seems that solution 1 is faster in practice.

#include <iostream>
#include <cctype>
#include <cassert>
#include <cstring>

using namespace std;

const int MAX_NUM_CASES = 5000;
const int MAX_LEN = 100000;
int occurrences[26];

string solve() {
	string str;
	cin >> str;
	int l = str.size();
	assert(l > 0 && l <= MAX_LEN);
	memset(occurrences, 0, sizeof occurrences);
	for (int i = 0; i < l; i++) {
		assert(islower(str[i]));
		occurrences[str[i] - 'a']++;
	}
	for (int i = 0; i < 26; i++) {
		if (occurrences[i] > (l + 1) / 2) {
			return "IMPOSSIBLE";
		}
	}
	char sol[MAX_LEN + 3];
	for (int i = 0; i < l; i++) {
		int remaining = l - i;
		int m = -1;
		for (int j = 0; j < 26; j++) {
			if (m == -1 || occurrences[j] > occurrences[m])
				m = j;
		}
		assert(occurrences[m] > 0);
		assert(remaining - occurrences[m] >= occurrences[m] - 1);
		// either we are forced to take the letter that occurs most...
		if (remaining - occurrences[m] == occurrences[m] - 1) {
			sol[i] = 'a' + m;
			occurrences[m]--;
			continue;
		}
		// ... or we take the alphabetically smallest available letter
		bool done = false;
		for (int j = 0; j < 26 && !done; j++) {
			char nextChar = 'a' + j;
			if (i > 0 && sol[i - 1] == nextChar)
				continue;
			if (occurrences[j] == 0)
				continue;
			sol[i] = nextChar;
			occurrences[j]--;
			done = true;
		}
		assert(done);
	}
	sol[l] = '\0';
	return string(sol);
}

int main() {
	int T;
	cin >> T;
	assert(T > 0 && T <= MAX_NUM_CASES);
	for (int i = 0; i < T; i++)
		cout << solve() << endl;
	return 0;
}
