// O(MAX_X + MAX_Y) solution using integers only.
// 
// In this solution, I'm going out of my way to use integers only. Instead of
// calculating ceil(sqrt(Z / D)), I will find the smallest integer n such that
// we have Z / D <= n^2.
// 
// In order to compare fractions, it is important that the numerators and
// denominators can be multiplied without overflow, so we have to use long long
// integers (64 bits). We should be fine since both Z and D fit in 32 bits.

#include <iostream>
#include <cassert>

using namespace std;

const int MAX_D = 100000000;
const int MAX_X = 10000;
const int MAX_Y = MAX_X;

struct frac {
	long long numerator, denominator;
	frac() : numerator(0), denominator(1) {}
	frac(int _n) : numerator(_n), denominator(1) {}
	frac(int _n, int _d) : numerator(_n), denominator(_d) {}
	bool operator<=(const frac& other) const {
		// potential for integer overflow:
		return numerator * other.denominator <= other.numerator * denominator;
	}
};

int solve() {
	int D, X, Y;
	cin >> D >> X >> Y;
	assert(D >= 1 && D <= MAX_D);
	assert(X >= -MAX_X && X <= MAX_X);
	assert(Y >= -MAX_Y && Y <= MAX_Y);
	int Z = X * X + Y * Y;
	if (Z < D)
		return (Z == 0 ? 0 : 2);
	frac quotient(Z, D);
	for (int numJumps = 1; numJumps <= MAX_X + MAX_Y; numJumps++) {
		frac square(numJumps * numJumps);
		if (quotient <= square)
			return numJumps;
	}
	// this should never happen:
	return -1;
}

int main() {
	int T;
	cin >> T;
	for (int i = 0; i < T; i++) {
		cout << solve() << endl;
	}
	return 0;
}
