// Solution to problem `Pacman'
// (Implicitly) construct graph with h*w*h*w nodes and do BFS.
//
// Version without classes and without dynamic arrays.
// Version that does not explicitly construct graph.
//
// Rudy van Vliet, 1 September, 2015


#include<iostream>
#include<cstring>

using namespace std;

enum Direction {South, East, North, West};
const int MaxDim = 50;
char grid[MaxDim][MaxDim+1];  // +1 to store EOS at read-in
bool endNode[MaxDim*MaxDim*MaxDim*MaxDim];
int queue[MaxDim*MaxDim*MaxDim*MaxDim],
    mydistance[MaxDim*MaxDim*MaxDim*MaxDim],
    parent[MaxDim*MaxDim*MaxDim*MaxDim];
Direction direction[MaxDim*MaxDim*MaxDim*MaxDim],
          path[MaxDim*MaxDim*MaxDim*MaxDim];
const char Pacman = 'P';
const char Wall = 'X';
const char Ghost = 'G';

//*************************************************************************

bool IntegerInRange (const char *variable, int val, int minVal, int maxVal)
{
  if (val>=minVal && val<=maxVal)
    return true;
  else
  { cout << variable << "=" << val << ", but should be in [" << minVal
         << "," << maxVal << "]" << endl;
    return false;
  }

}  // IntegerInRange

//*************************************************************************

int determineNumber (int h, int w, int i1, int j1, int i2, int j2)
{ return (i1*w*h*w + j1*h*w + i2*w + j2);
}

void decodeNumber (int nr, int h, int w, int &i1, int &j1, int &i2, int &j2)
{ 
  j2 = nr%w;
  nr = nr/w;
  i2 = nr%h;
  nr = nr/h;
  j1 = nr%w;
  nr = nr/w;
  i1 = nr;

}  // decodeNumber

//*************************************************************************

  // determine position south of (i1,j1)
void neighbourSouth (int h, int i1, int j1, int &i3, int &j3)
{
  i3 = (i1+1)%h;
  j3 = j1;
  if (grid[i3][j3]==Wall)
    i3 = i1;
}

  // determine position east of (i1,j1)
void neighbourEast (int w, int i1, int j1, int &i3, int &j3)
{
  i3 = i1;
  j3 = (j1+1)%w;
  if (grid[i3][j3]==Wall)
    j3 = j1;
}

  // determine position north of (i1,j1)
void neighbourNorth (int h, int i1, int j1, int &i3, int &j3)
{
  i3 = (i1-1+h)%h;
  j3 = j1;
  if (grid[i3][j3]==Wall)
    i3 = i1;
}

  // determine position west of (i1,j1)
void neighbourWest (int w, int i1, int j1, int &i3, int &j3)
{
  i3 = i1;
  j3 = (j1-1+w)%w;
  if (grid[i3][j3]==Wall)
    j3 = j1;
}

//*************************************************************************

void initGraph (int h, int w)
{ int size,
      nr,
      i, j;

  size = h*w*h*w;

  for (nr=0;nr<size;nr++)
    endNode[nr] = false;

  for (i=0;i<h;i++)
    for (j=0;j<w;j++)
    { nr = determineNumber (h, w, i, j, i, j);
      endNode[nr] = true;
    }
      
}

//*************************************************************************

// Test if a neighbour nr1 of the current node nr0 in the BFS
// * is visited for the first time
// * and if so, if it is an endNode
// If the first condition is met, and the second is not,
// then add nr1 to the queue.
//
// Return true: if both conditions are met
//        false: otherwise
bool testNeighbourBFS (int nr0, int nr1, Direction direct, int newDist,
                       int &last)
{ bool found;

  found = false;

  if (newDist<mydistance[nr1])  // not reached before
  { mydistance[nr1] = newDist;
    parent[nr1] = nr0;
    direction[nr1] = direct;
    if (endNode[nr1])
      found = true;
    else
    { last ++;
      queue[last] = nr1;
    }
  }

  return found;

}  // testNeighbourBFS

//*************************************************************************

void BFS (int h, int w, int nr0)
{ int size,
      newDist,
      d,
      first, last,
      nr, nr1,
      i1, j1, i2, j2,
      i3, j3, i4, j4;
  bool found;

  size = h*w*h*w;

  if (endNode[nr0])
    cout << 0 << ' ' << endl;
  else
  {
    first = 0;
    last = -1;

    for (nr=0;nr<size;nr++)
      mydistance[nr] = size+1;

    mydistance[nr0] = 0;
    parent[nr0] = -1;

    last ++;
    queue[last] = nr0;
    found = false;
    while (!found && last>=first)  // queue not empty
    { nr0 = queue[first];
      first ++;
      newDist = mydistance[nr0]+1;

      decodeNumber (nr0, h, w, i1, j1, i2, j2);

      neighbourSouth (h, i1, j1, i3, j3);
      neighbourSouth (h, i2, j2, i4, j4);
      if (grid[i3][j3]!=Ghost && grid[i4][j4]!=Ghost)
      { nr1 = determineNumber (h, w, i3, j3, i4, j4);
        if (nr0!=nr1)
        {
          found = testNeighbourBFS (nr0, nr1, South, newDist, last);
        }
      }

      if (!found)
      { neighbourEast (w, i1, j1, i3, j3);
        neighbourEast (w, i2, j2, i4, j4);
        if (grid[i3][j3]!=Ghost && grid[i4][j4]!=Ghost)
        { nr1 = determineNumber (h, w, i3, j3, i4, j4);
          if (nr0!=nr1)
          {
            found = testNeighbourBFS (nr0, nr1, East, newDist, last);
          }
        }
      }  // !found

      if (!found)
      {
        neighbourNorth (h, i1, j1, i3, j3);
        neighbourNorth (h, i2, j2, i4, j4);
        if (grid[i3][j3]!=Ghost && grid[i4][j4]!=Ghost)
        { nr1 = determineNumber (h, w, i3, j3, i4, j4);
          if (nr0!=nr1)
          {
            found = testNeighbourBFS (nr0, nr1, North, newDist, last);
          }
        }
      }  // !found

      if (!found)
      {
        neighbourWest (w, i1, j1, i3, j3);
        neighbourWest (w, i2, j2, i4, j4);
        if (grid[i3][j3]!=Ghost && grid[i4][j4]!=Ghost)
        { nr1 = determineNumber (h, w, i3, j3, i4, j4);
          if (nr0!=nr1)
          {
            found = testNeighbourBFS (nr0, nr1, West, newDist, last);
          }
        }
      }  // !found


    }  // while queue not empty

    if (found)  // path found, nr1 is endnode
    { cout << mydistance[nr1] << ' ';
      nr = nr1;
      while (mydistance[nr]!=0)
      { path[mydistance[nr]] = direction[nr];
        nr = parent[nr];
      }
      d = 1;
      for (d=1;d<=mydistance[nr1];d++)
      { switch (path[d])
        { case South: cout << 'S';
                      break;
          case East: cout << 'E';
                     break;
          case North: cout << 'N';
                      break;
          case West: cout << 'W';
                     break;
        }
      }
      cout << endl; 
      
    }  // path found
    else
      cout << "IMPOSSIBLE\n";
  
  }  // else

}  // BFS

//*************************************************************************

int main()
{ int nInst, inst;
  int h, w,
      i, j,
      i1, j1, i2, j2,
      nr0;
  int Pfound;

  cin >> nInst;
  for (inst=1;inst<=nInst;inst++)
  {
    cin >> h >> w;
    if (IntegerInRange ("h", h, 2, MaxDim)
        && IntegerInRange ("w", w, 2, MaxDim))
    {
      for (i=0;i<h;i++)
        cin >> grid[i];

        // determine position of Pacmen
      Pfound = 0;
      for (i=0;i<h;i++)
        for (j=0;j<w;j++)
          if (grid[i][j]==Pacman)
          { if (Pfound==0)
            { i1 = i;
              j1 = j;
              Pfound ++;
            }
            else
            { i2 = i;
              j2 = j;
              Pfound ++;
            }
          }

      if (Pfound==2)  // input is OK
      {
        nr0 = determineNumber (h, w, i1, j1, i2, j2);
          // start node of search

        initGraph (h, w);

        BFS (h, w, nr0);

      }
      else
        cout << "Grid does not contain exactly two Pacmen.\n";

    }  // if IntegerInRange
    else
    {   // ignore rest of input
      return 1;
    }

  }

  return 0;
}
