// Solution to problem `Pacman'
// Construct graph with h*w*h*w nodes and do BFS.
//
// Rudy van Vliet, 1 September, 2015


#include<iostream>
#include<cstring>

using namespace std;

const int MaxDim = 50;
char grid[MaxDim][MaxDim+1];  // +1 to store EOS at read-in
const char Pacman = 'P';
const char Wall = 'X';
const char Ghost = 'G';
enum Direction {South, East, North, West};

//*************************************************************************

bool IntegerInRange (const char *variable, int val, int minVal, int maxVal)
{
  if (val>=minVal && val<=maxVal)
    return true;
  else
  { cout << variable << "=" << val << ", but should be in [" << minVal
         << "," << maxVal << "]" << endl;
    return false;
  }

}  // IntegerInRange

//*************************************************************************

class Grid
{ public:
    Grid (int valueh, int valuew)
    { h = valueh;
      w = valuew;
    }

    // for programming convenience,
    // we left out from this class the actual grid...

    int determineNumber (int i1, int j1, int i2, int j2)
    { return (i1*w*h*w + j1*h*w + i2*w + j2);
    }

      // determine position south of (i1,j1)
    void neighbourSouth (int i1, int j1, int &i3, int &j3)
    {
      i3 = (i1+1)%h;
      j3 = j1;
      if (grid[i3][j3]==Wall)
        i3 = i1;
    }
    
      // determine position east of (i1,j1)
    void neighbourEast (int i1, int j1, int &i3, int &j3)
    {
      i3 = i1;
      j3 = (j1+1)%w;
      if (grid[i3][j3]==Wall)
        j3 = j1;
    }
    
      // determine position north of (i1,j1)
    void neighbourNorth (int i1, int j1, int &i3, int &j3)
    {
      i3 = (i1-1+h)%h;
      j3 = j1;
      if (grid[i3][j3]==Wall)
        i3 = i1;
    }
    
      // determine position west of (i1,j1)
    void neighbourWest (int i1, int j1, int &i3, int &j3)
    {
      i3 = i1;
      j3 = (j1-1+w)%w;
      if (grid[i3][j3]==Wall)
        j3 = j1;
    }

  private:
    int h, w;

};

//*************************************************************************

class Neighbour
{ public:
    Neighbour (int valuenumber, Direction valuedirect, Neighbour* valuenext)
    { number = valuenumber;
      direct = valuedirect;
      next = valuenext;
    }

    int getNumber ()
    { return number;
    }

    Direction getDirection ()
    { return direct;
    }

    Neighbour* getNext ()
    { return next;
    }

  private:
    int number;  // which node/number is the neighbour
    Direction direct;
    Neighbour* next;
};

//*************************************************************************

class Graph
{ public:
    Graph (int valueh, int valuew, Grid *gri)
      // argument gri is used only to determine endNode's
    { int nr,
          i, j;

      h = valueh;
      w = valuew;

      size = valueh*valuew*valueh*valuew;
      neighbours = new Neighbour*[size];
      for (nr=0;nr<size;nr++)
        neighbours[nr] = NULL;

      endNode = new bool[size];
      for (nr=0;nr<size;nr++)
        endNode[nr] = false;

      for (i=0;i<h;i++)
        for (j=0;j<w;j++)
        { nr = gri->determineNumber (i, j, i, j);
          endNode[nr] = true;
        }
          
    }

    ~Graph ()
    { int nr;
      Neighbour *walker,
                *tmp;

      for (nr=0;nr<size;nr++)
      { walker = neighbours[nr];
        while (walker!=NULL)
        { tmp = walker -> getNext();
          delete walker;
          walker = tmp;
        }

      }
      delete [] neighbours;
      delete [] endNode;
    }

    void addEdge (int nr1, int nr2, Direction direct)
    { neighbours[nr1] = new Neighbour (nr2, direct, neighbours[nr1]);
    }

    void BFS (int nr0)
    { int *distance,
          newDist,
          d,
          *queue,
          *parent,
          first, last,
          nr, nr1;
      bool found;
      Neighbour *walker;
      Direction *direction,
                *path;

      if (endNode[nr0])
        cout << 0 << ' ' << endl;
      else
      { distance = new int[size];
        queue = new int[size];
        parent = new int[size];
        direction = new Direction[size];
        first = 0;
        last = -1;

        for (nr=0;nr<size;nr++)
          distance[nr] = size+1;

        distance[nr0] = 0;
        parent[nr0] = -1;

        last ++;
        queue[last] = nr0;
        found = false;
        while (!found && last>=first)  // queue not empty
        { nr0 = queue[first];
          first ++;
          newDist = distance[nr0]+1;

          walker = neighbours[nr0];
          while (!found && walker!=NULL)
          { nr1 = walker->getNumber();
            if (newDist<distance[nr1])  // not reached before
            { distance[nr1] = newDist;
              parent[nr1] = nr0;
              direction[nr1] = walker->getDirection();
              if (endNode[nr1])
                found = true;
              else
              { last ++;
                queue[last] = nr1;
              }
            }
            walker=walker->getNext();
          }  // while walker

        }  // while queue not empty

        if (found)  // path found, nr1 is endnode
        { cout << distance[nr1] << ' ';
          path = new Direction[distance[nr1]+1];
          nr = nr1;
          while (distance[nr]!=0)
          { path[distance[nr]] = direction[nr];
            nr = parent[nr];
          }
          d = 1;
          for (d=1;d<=distance[nr1];d++)
          { switch (path[d])
            { case South: cout << 'S';
                          break;
              case East: cout << 'E';
                         break;
              case North: cout << 'N';
                          break;
              case West: cout << 'W';
                         break;
            }
          }
          cout << endl; 
          delete [] path;
          
        }  // path found
        else
          cout << "IMPOSSIBLE\n";
      
        delete [] distance;
        delete [] queue;
        delete [] parent;
        delete [] direction;
      }  // else

    }  // BFS

  private:
    int h, w,
        size;
    Neighbour* *neighbours;
    bool* endNode;
};

//*************************************************************************

int main()
{ int nInst, inst;
  Graph *G;
  Grid  *gri;
  int h, w,
      i, j,
      i1, j1,
      i2, j2,
      i3, j3,
      i4, j4,
      nr0,
      nr1, nr2;
  int Pfound;

  cin >> nInst;
  for (inst=1;inst<=nInst;inst++)
  {
    cin >> h >> w;
    if (IntegerInRange ("h", h, 2, MaxDim)
        && IntegerInRange ("w", w, 2, MaxDim))
    {

      gri = new Grid (h, w);
      for (i=0;i<h;i++)
        cin >> grid[i];

        // determine position of Pacmen
      Pfound = 0;
      for (i=0;i<h;i++)
        for (j=0;j<w;j++)
          if (grid[i][j]==Pacman)
          { if (Pfound==0)
            { i1 = i;
              j1 = j;
              Pfound ++;
            }
            else
            { i2 = i;
              j2 = j;
              Pfound ++;
            }
          }

      if (Pfound==2)  // input is OK
      {
        nr0 = gri->determineNumber (i1, j1, i2, j2);  // start node of search

          // construct graph corresponding to the grid
        G = new Graph (h, w, gri);

        for (i1=0;i1<h;i1++)
          for (j1=0;j1<w;j1++)
            for (i2=0;i2<h;i2++)
              for (j2=0;j2<w;j2++)
              { nr1 = gri->determineNumber (i1, j1, i2, j2);

                gri->neighbourSouth (i1, j1, i3, j3);
                gri->neighbourSouth (i2, j2, i4, j4);
                if (grid[i3][j3]!=Ghost && grid[i4][j4]!=Ghost)
                { nr2 = gri->determineNumber (i3, j3, i4, j4);
                  if (nr1!=nr2)
                    G->addEdge (nr1, nr2, South);
                }

                gri->neighbourEast (i1, j1, i3, j3);
                gri->neighbourEast (i2, j2, i4, j4);
                if (grid[i3][j3]!=Ghost && grid[i4][j4]!=Ghost)
                { nr2 = gri->determineNumber (i3, j3, i4, j4);
                  if (nr1!=nr2)
                    G->addEdge (nr1, nr2, East);
                }

                gri->neighbourNorth (i1, j1, i3, j3);
                gri->neighbourNorth (i2, j2, i4, j4);
                if (grid[i3][j3]!=Ghost && grid[i4][j4]!=Ghost)
                { nr2 = gri->determineNumber (i3, j3, i4, j4);
                  if (nr1!=nr2)
                    G->addEdge (nr1, nr2, North);
                }

                gri->neighbourWest (i1, j1, i3, j3);
                gri->neighbourWest (i2, j2, i4, j4);
                if (grid[i3][j3]!=Ghost && grid[i4][j4]!=Ghost)
                { nr2 = gri->determineNumber (i3, j3, i4, j4);
                  if (nr1!=nr2)
                    G->addEdge (nr1, nr2, West);
                }
              }
                
        G->BFS (nr0);

        delete G;
      }
      else
        cout << "Grid does not contain exactly two Pacmen.\n";

      delete gri;

    }  // if IntegerInRange
    else
    {   // ignore rest of input
      return 1;
    }

  }

  return 0;
}
